@@ -9,10 +9,10 @@ ATTR_INDEX_LEVEL: Final[str] = "{}IndexLevel"
 ATTR_NAME: Final[str] = "name"
 ATTR_VALUE: Final[str] = "value"
 
-URL_INDEXES: Final[str] = "http://api.gios.gov.pl/pjp-api/rest/aqindex/getIndex/{}"
-URL_SENSOR: Final[str] = "http://api.gios.gov.pl/pjp-api/rest/data/getData/{}"
-URL_STATION: Final[str] = "http://api.gios.gov.pl/pjp-api/rest/station/sensors/{}"
-URL_STATIONS: Final[str] = "http://api.gios.gov.pl/pjp-api/rest/station/findAll"
+URL_INDEXES: Final[str] = "https://api.gios.gov.pl/pjp-api/rest/aqindex/getIndex/{}"
+URL_SENSOR: Final[str] = "https://api.gios.gov.pl/pjp-api/rest/data/getData/{}"
+URL_STATION: Final[str] = "https://api.gios.gov.pl/pjp-api/rest/station/sensors/{}"
+URL_STATIONS: Final[str] = "https://api.gios.gov.pl/pjp-api/rest/station/findAll"
 
 POLLUTANT_MAP = {
     "benzen": "benzene",
